@@ -88,13 +88,18 @@ def steinalp(f,numfac):
         return fsep
 
 
-def tsfill(valin,dtin,dtout):
+def tsfill(valin,dtin,dtout,rev=False):
     ''' purpose: regrid timeseries... fill missing timesteps in a timeseries with nan values, or leave out unwanted timesteps
     valin: time series values
     dtin: time steps of the timeseries
     dtout: desired output timesteps
     '''
 
+    if rev:
+        valin = valin[::-1]
+        dtin = dtin[::-1]
+        dtout = dtout[::-1]
+
     valout = zeros([len(dtout)]+list(np.array(valin).shape[1:]))*nan
     lendtin = len(dtin)
     idtin = 0
@@ -104,7 +109,10 @@ def tsfill(valin,dtin,dtout):
     
         if edt == dtin[idtin]:
             valout[idt] = valin[idtin]
-    return valout
+    if rev:
+        return valout[::-1]
+    else: 
+       return valout
 
 
 def mergedata(x):
